==> estateplat-common-1.1.0-20160726.011606-129-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsTdsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡土地所有权
 */
@Table(name = "GD_LS_TDSYQ")
public class GdLsTdsyq implements Serializable {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String qlid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地证号
     */
    private String tdzh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地ID
     */
    private String tdid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记类型
     */
    private String djlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记原因
     */
    private String djyy;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 房屋ID
     */
    private String fwid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目主键
     */
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 独用面积
     */
    private Double dymj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 分摊面积
     */
    private Double ftmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地总面积
     */
    private Double tdzmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 农用地面积
     */
    private Double nyd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 耕地面积
     */
    private Double gd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 园地面积
     */
    private Double yd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地面积
     */
    private Double ld;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 牧草地面积
     */
    private Double mcd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 其他农用地面积
     */
    private Double qtnyd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 建设用地面积
     */
    private Double jsyd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 未利用地面积
     */
    private Double wlyd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 是否是使用权
     */
    private String issynq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 创建人ID
     */
    private String cjrid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 原产权证号
     */
    private String yqzh;

    public Double getTdzmj() {
        return tdzmj;
    }

    public void setTdzmj(Double tdzmj) {
        this.tdzmj = tdzmj;
    }

    public Double getNyd() {
        return nyd;
    }

    public void setNyd(Double nyd) {
        this.nyd = nyd;
    }

    public Double getGd() {
        return gd;
    }

    public void setGd(Double gd) {
        this.gd = gd;
    }

    public Double getYd() {
        return yd;
    }

    public void setYd(Double yd) {
        this.yd = yd;
    }

    public Double getLd() {
        return ld;
    }

    public void setLd(Double ld) {
        this.ld = ld;
    }

    public Double getMcd() {
        return mcd;
    }

    public void setMcd(Double mcd) {
        this.mcd = mcd;
    }

    public Double getQtnyd() {
        return qtnyd;
    }

    public void setQtnyd(Double qtnyd) {
        this.qtnyd = qtnyd;
    }

    public Double getJsyd() {
        return jsyd;
    }

    public void setJsyd(Double jsyd) {
        this.jsyd = jsyd;
    }

    public Double getWlyd() {
        return wlyd;
    }

    public void setWlyd(Double wlyd) {
        this.wlyd = wlyd;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getTdid() {
        return tdid;
    }

    public void setTdid(String tdid) {
        this.tdid = tdid;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getFwid() {
        return fwid;
    }

    public void setFwid(String fwid) {
        this.fwid = fwid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getIssynq() {
        return issynq;
    }

    public void setIssynq(String issynq) {
        this.issynq = issynq;
    }


}

==> estateplat-common-1.2.4-20220613.134657-1042-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsTdsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡土地所有权
 */
@Table(name = "GD_LS_TDSYQ")
public class GdLsTdsyq implements Serializable {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String qlid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地证号
     */
    private String tdzh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记类型
     */
    private String djlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记原因
     */
    private String djyy;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目主键
     */
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 独用面积
     */
    private Double dymj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 分摊面积
     */
    private Double ftmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 土地总面积
     */
    private Double tdzmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 农用地面积
     */
    private Double nyd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 耕地面积
     */
    private Double gd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 园地面积
     */
    private Double yd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地面积
     */
    private Double ld;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 牧草地面积
     */
    private Double mcd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 其他农用地面积
     */
    private Double qtnyd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 建设用地面积
     */
    private Double jsyd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 未利用地面积
     */
    private Double wlyd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 是否是使用权
     */
    private String issynq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 土地证记事
     */
    private String tdzjs;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登簿人
     */
    private String dbr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登记时间
     */
    private Date djsj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登记卡续表内容
     */
    private String djkxbnr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 档案业务号
     */
    private String daywh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 用途
     */
    private String yt;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 用途2
     */
    private String yt2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 用途3
     */
    private String yt3;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 起始日期
     */
    private Date qsrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 终止日期
     */
    private Date zzrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 起始日期2
     */
    private Date qsrq2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 终止日期2
     */
    private Date zzrq2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 起始日期3
     */
    private Date qsrq3;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 终止日期3
     */
    private Date zzrq3;

    public Double getTdzmj() {
        return tdzmj;
    }

    public void setTdzmj(Double tdzmj) {
        this.tdzmj = tdzmj;
    }

    public Double getNyd() {
        return nyd;
    }

    public void setNyd(Double nyd) {
        this.nyd = nyd;
    }

    public Double getGd() {
        return gd;
    }

    public void setGd(Double gd) {
        this.gd = gd;
    }

    public Double getYd() {
        return yd;
    }

    public void setYd(Double yd) {
        this.yd = yd;
    }

    public Double getLd() {
        return ld;
    }

    public void setLd(Double ld) {
        this.ld = ld;
    }

    public Double getMcd() {
        return mcd;
    }

    public void setMcd(Double mcd) {
        this.mcd = mcd;
    }

    public Double getQtnyd() {
        return qtnyd;
    }

    public void setQtnyd(Double qtnyd) {
        this.qtnyd = qtnyd;
    }

    public Double getJsyd() {
        return jsyd;
    }

    public void setJsyd(Double jsyd) {
        this.jsyd = jsyd;
    }

    public Double getWlyd() {
        return wlyd;
    }

    public void setWlyd(Double wlyd) {
        this.wlyd = wlyd;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getIssynq() {
        return issynq;
    }

    public void setIssynq(String issynq) {
        this.issynq = issynq;
    }

    public String getTdzjs() {
        return tdzjs;
    }

    public void setTdzjs(String tdzjs) {
        this.tdzjs = tdzjs;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDjkxbnr() {
        return djkxbnr;
    }

    public void setDjkxbnr(String djkxbnr) {
        this.djkxbnr = djkxbnr;
    }

    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYt2() {
        return yt2;
    }

    public void setYt2(String yt2) {
        this.yt2 = yt2;
    }

    public String getYt3() {
        return yt3;
    }

    public void setYt3(String yt3) {
        this.yt3 = yt3;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public Date getQsrq2() {
        return qsrq2;
    }

    public void setQsrq2(Date qsrq2) {
        this.qsrq2 = qsrq2;
    }

    public Date getZzrq2() {
        return zzrq2;
    }

    public void setZzrq2(Date zzrq2) {
        this.zzrq2 = zzrq2;
    }

    public Date getQsrq3() {
        return qsrq3;
    }

    public void setQsrq3(Date qsrq3) {
        this.qsrq3 = qsrq3;
    }

    public Date getZzrq3() {
        return zzrq3;
    }

    public void setZzrq3(Date zzrq3) {
        this.zzrq3 = zzrq3;
    }
}
